<?php

/**
 * Class Affilibee_Settings
 *
 * This class handles the settings for the Affilibee plugin.
 */
class Affilibee_Settings {

    /**
     * Initialize the settings by adding the admin_init action.
     */
    public static function init() {
        add_action('admin_init', array(__CLASS__, 'register_settings'));
        add_action('admin_notices', array(__CLASS__, 'check_api_token'));
    }

    /**
     * Register the settings, sections, and fields for the Affilibee plugin.
     */
    public static function register_settings() {
        register_setting('affilibee_settings_group', 'affilibee_api_token', array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default' => '',
        ));
    }

    /**
     * Render the WooCommerce settings fields.
     */
    public static function render() {
        woocommerce_admin_fields(self::get_wc_settings_fields());
    }

    /**
     * Save the WooCommerce settings.
     */
    public static function save() {
        woocommerce_update_options(self::get_wc_settings_fields());
    }

    /**
     * Get the WooCommerce settings fields.
     *
     * @return array The WooCommerce settings fields.
     */
    private static function get_wc_settings_fields() {
        return array(
            array(
                'title' => __('Affilibee Settings', 'affilibee'),
                'type'  => 'title',
                'id'    => 'affilibee_settings_section'
            ),
            array(
                'type' => 'title',
                'id'   => 'affilibee_intro',
                'desc' => '<p>' . __('This plugin integrates Affilibee with WooCommerce. To get started, you’ll need a merchant account on <a target="_blank" href=' . Affilibee_Config::AFFILIBEE_URL . '>affilibee.com</a>.</p>') . 
                          '<p>' . __('Follow the installation instructions in our <a target="_blank" href=' . Affilibee_Config::AFFILIBEE_DOC_URL . '>documentation</a>.</p> '),
            ),
            array(
                'title' => __('API Token', 'affilibee'),
                'id'    => 'affilibee_api_token',
                'type'  => 'text',
                'desc'  => __('Enter your Affilibee API Token.', 'affilibee'),
            ),
            array(
                'type' => 'sectionend',
                'id'   => 'affilibee_settings_section'
            ),
        );
    }

    /**
     * Check if the API token is set and display a warning if it is missing.
     */
    public static function check_api_token() {
        $api_token = get_option('affilibee_api_token', '');
        if (empty($api_token)) {
            ?>
            <div class="notice notice-warning">
                <p><?php _e('Please enter your API token in the <a href="' . admin_url('admin.php?page=wc-settings&tab=affilibee') . '">Affilibee settings</a> to finalize the setup.', 'affilibee'); ?></p>
            </div>
            <?php
        }
    }
}