<?php
/**
 * Plugin Name: Affilibee for WooCommerce
 * Description: Integrates the Affilibee tracking code into your WooCommerce store.
 * Author: Affilibee
 * Author URI: https://www.affilibee.com
 * Version: 1.0
 * Requires at least: 5.3
 * WC requires at least: 5.0
 * Requires PHP: 7.4
 */

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Affilibee Plugin
 *
 * This file is the main plugin file for the Affilibee plugin. It defines the
 * plugin directory and file constants, and includes the necessary class files
 * for the plugin to function.
 *
 * @package Affilibee
 */

// Define the plugin directory and file constants
define('AFFILIBEE_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('AFFILIBEE_PLUGIN_FILE', __FILE__);

// Include the necessary class files
require_once AFFILIBEE_PLUGIN_DIR . 'includes/class-affilibee-config.php';
require_once AFFILIBEE_PLUGIN_DIR . 'includes/class-affilibee-activator.php';
require_once AFFILIBEE_PLUGIN_DIR . 'includes/class-affilibee-database.php';
require_once AFFILIBEE_PLUGIN_DIR . 'includes/class-affilibee-cookie-handler.php';
require_once AFFILIBEE_PLUGIN_DIR . 'includes/class-affilibee-order-meta-handler.php';
require_once AFFILIBEE_PLUGIN_DIR . 'includes/class-affilibee-order-completion.php';
require_once AFFILIBEE_PLUGIN_DIR . 'includes/class-affilibee-display.php';
require_once AFFILIBEE_PLUGIN_DIR . 'includes/class-affilibee-request-handler.php';
require_once AFFILIBEE_PLUGIN_DIR . 'admin/class-affilibee-admin-menu.php';
require_once AFFILIBEE_PLUGIN_DIR . 'admin/class-affilibee-settings.php';
require_once AFFILIBEE_PLUGIN_DIR . 'admin/class-affilibee-requests-list.php';
require_once AFFILIBEE_PLUGIN_DIR . 'admin/class-affilibee-requests-detail.php';

/**
 * Initializes the Affilibee plugin by activating necessary components and handlers.
 *
 * @return void
 */
function affilibee_init()
{
    Affilibee_Activator::activate();
    Affilibee_Admin_Menu::init();
    Affilibee_Settings::init();
    Affilibee_Cookie_Handler::init();
    Affilibee_Order_Meta_Handler::init();
    Affilibee_Order_Completion::init();
    Affilibee_Display::init();
}
add_action('plugins_loaded', 'affilibee_init');

/**
 * Add a 'Settings' link to the plugin action links.
 *
 * @param array $links Existing plugin action links.
 * @return array Modified plugin action links with 'Settings' added.
 */
function affilibee_add_settings_link($links)
{
    $settings_link = '<a href="' . admin_url('admin.php?page=wc-settings&tab=affilibee') . '">' . __('Settings', 'affilibee') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}
$plugin_basename = plugin_basename(__FILE__);
add_filter('plugin_action_links_' . $plugin_basename, 'affilibee_add_settings_link');