<?php

/**
 * Class Affilibee_Config
 *
 * This class defines configuration constants and methods for the Affilibee plugin.
 *
 * Constants:
 * - PLUGIN_VERSION: The version of the plugin.
 * - API_URL: The URL for the API endpoint to create orders.
 * - DB_TABLE: The name of the database table used by the plugin.
 * - COOKIE_NAME: The name of the cookie used to store the affiliate slug.
 * - COOKIE_EXPIRY: The expiry time for the cookie in seconds (30 days).
 * - MINIMUM_PHP_VERSION: The minimum required PHP version for the plugin.
 * - MINIMUM_WP_VERSION: The minimum required WordPress version for the plugin.
 * - MINIMUM_WC_VERSION: The minimum required WooCommerce version for the plugin.
 * - AFFILIBEE_URL_PARAM: The URL parameter key.
 * - AFFILIBEE_DOC_URL: The URL for the WooCommerce documentation.
 * - META_KEY_AFFILIATE_SLUG: The meta key used to store the affiliate slug.
 * - REQUEST_TYPE_ORDER_SUBMISSION: The type of request for order submission.
 */
class Affilibee_Config {
    const PLUGIN_VERSION = '1.0';
    const API_URL = 'https://affilibee.com/api/orders/create';
    const DB_TABLE = 'affilibee_requests';
    const COOKIE_NAME = 'affilibee_affiliate_slug';
    const COOKIE_EXPIRY = 86400 * 30; // 30 days
    const MINIMUM_PHP_VERSION = '7.4.0';
    const MINIMUM_WP_VERSION = '5.3';
    const MINIMUM_WC_VERSION = '5.0';
    const AFFILIBEE_URL_PARAM = 'affiliate';
    const AFFILIBEE_URL = 'https://affilibee.com';
    const AFFILIBEE_DOC_URL = 'https://affilibee.com/docs/integrations/woocommerce';
    const META_KEY_AFFILIATE_SLUG = '_affilibee_affiliate_slug';
    const REQUEST_TYPE_ORDER_SUBMISSION = 'order_submission';
}