<?php

class Affilibee_Database
{
    /**
     * Create the necessary database tables.
     */
    public static function create_tables()
    {
        global $wpdb;
        $requests_table = $wpdb->prefix . Affilibee_Config::DB_TABLE;
        $charset_collate = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE IF NOT EXISTS $requests_table (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            type varchar(50) NOT NULL,
            success_status TINYINT(1) NOT NULL DEFAULT 0,
            order_id bigint(20) DEFAULT NULL,
            request_payload longtext NOT NULL,
            response_payload longtext NOT NULL,
            created_at datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
            PRIMARY KEY (id)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }

    /**
     * Get all requests.
     */
    public static function get_requests($limit = null, $offset = null)
    {
        global $wpdb;
        $table_name = $wpdb->prefix . 'affilibee_requests';

        $sql = "SELECT * FROM {$table_name} ORDER BY created_at DESC";

        if ($limit !== null) {
            $sql .= $wpdb->prepare(" LIMIT %d", $limit);
            if ($offset !== null) {
                $sql .= $wpdb->prepare(" OFFSET %d", $offset);
            }
        }

        return $wpdb->get_results($sql);
    }

    /**
     * Get the count of all requests.
     */
    public static function get_requests_count()
    {
        global $wpdb;
        $table_name = $wpdb->prefix . 'affilibee_requests';
        return $wpdb->get_var("SELECT COUNT(*) FROM {$table_name}");
    }

    /**
     * Get a single request by ID.
     */
    public static function get_request($id)
    {
        global $wpdb;
        $table = $wpdb->prefix . Affilibee_Config::DB_TABLE;
        return $wpdb->get_row(
            $wpdb->prepare(
                "SELECT * FROM {$table} WHERE id = %d",
                $id
            )
        );
    }

    /**
     * Retrieve the API Token from WordPress options.
     *
     * @return string
     */
    public static function get_api_token()
    {
        return get_option('affilibee_api_token', '');
    }

    /**
     * Retrieve the segment slugs for a given product.
     *
     * @param int $product_id
     * @return string
     */
    public static function get_product_segment_slugs($product_id)
    {
        $terms = get_the_terms($product_id, 'product_cat');
        $slugs = array();
        if (is_array($terms)) {
            $slugs = array_map(function ($term) {
                return $term->slug;
            }, $terms);
        }
        return implode(',', $slugs);
    }
}