<?php

class Affilibee_Order_Completion
{
    public static function init()
    {
        add_action('woocommerce_order_status_completed', array(__CLASS__, 'handle_order_completion'));
    }

    /**
     * Handles the completion of an order by sending order details to the Affilibee API and logging the response.
     *
     * @param int $order_id The ID of the completed order.
     *
     * @global wpdb $wpdb WordPress database abstraction object.
     */
    public static function handle_order_completion($order_id)
    {
        $order = wc_get_order($order_id);
        if (!$order)
            return;

        $affiliate_slug = $order->get_meta(Affilibee_Config::META_KEY_AFFILIATE_SLUG);

        if ($affiliate_slug) {
            $body = array(
                'affiliate_slug' => $affiliate_slug,
                'order_no' => $order_id,
                'total_shipping_value' => (float) $order->get_shipping_total(),
                'total_discount_value' => (float) $order->get_discount_total(),
                'currency_code' => $order->get_currency(),
                'order_rows' => array_map(function ($item) {
                    $product_id = $item->get_variation_id() ? $item->get_variation_id() : $item->get_product_id();
                    $product = wc_get_product($product_id);
                    $parent_id = ($product && $product->get_parent_id()) ? $product->get_parent_id() : $product_id;
                    $segment_slugs = Affilibee_Database::get_product_segment_slugs($parent_id);

                    return array(
                        'product_sku' => ($product && $product->get_sku()) ? $product->get_sku() : 'missing',
                        'product_name' => $item->get_name(),
                        'segment_slug' => $segment_slugs,
                        'price_value' => (float) $item->get_total(),
                        'tax_value' => (float) $item->get_total_tax(),
                        'quantity' => (int) $item->get_quantity(),
                    );
                }, $order->get_items()),
                'customer' => array(
                    'name' => $order->get_billing_first_name() . ' ' . $order->get_billing_last_name(),
                    'email' => $order->get_billing_email(),
                ),
            );

            $success = Affilibee_Request_Handler::send_request(Affilibee_Config::REQUEST_TYPE_ORDER_SUBMISSION, $order_id, $body);

            if (!$success) {
                // Handle logging failure if necessary
                // For example, display an admin notice
            }
        }
    }
}