<?php

class Affilibee_Request_Handler {
    /**
     * Send a request to the Affilibee API and log the response.
     *
     * @param string $type       The type of request (e.g., order_submission).
     * @param int    $order_id   The ID of the related order.
     * @param array  $payload    The request payload to send.
     *
     * @return bool True on success, false on failure.
     */
    public static function send_request($type, $order_id, $payload) {
        $url = Affilibee_Config::API_URL;
        $token = Affilibee_Database::get_api_token();

        $response = wp_remote_post($url, array(
            'headers' => array(
                'Authorization' => 'Bearer ' . $token,
                'Content-Type'  => 'application/json',
                'Accept'  => 'application/json',
            ),
            'body'    => wp_json_encode($payload),
            'timeout' => 15,
            'sslverify' => true,
        ));

        $success = 0;
        if (!is_wp_error($response)) {
            $code = wp_remote_retrieve_response_code($response);
            if ($code >= 200 && $code < 300) {
                $success = 1;
            }
        }

        global $wpdb;
        $inserted = $wpdb->insert(
            $wpdb->prefix . Affilibee_Config::DB_TABLE,
            array(
                'order_id'         => $order_id,
                'type'             => $type,
                'request_payload'  => wp_json_encode($payload),
                'response_payload' => wp_json_encode($response),
                'success_status'   => $success,
            ),
            array('%d', '%s', '%s', '%s', '%d')
        );

        return $inserted ? true : false;
    }
}